@@ -1,6 +1,7 @@
 #include <pybind11/numpy.h>
 #include <pybind11/pybind11.h>
 
+#include "bert.cc.cu"
 #include "gpt.cc.cu"
 #include "transformer.cc.cu"
 #include "transformer_decoder.cc.cu"
@@ -31,4 +32,10 @@ PYBIND11_MODULE(inference, m) {
            py::return_value_policy::reference_internal, py::arg("input_seq"),
            py::arg("sampling_method") = "topk", py::arg("topk") = 1,
            py::arg("topp") = 0.75);
+
+  py::class_<lightseq::cuda::Bert>(m, "Bert")
+      .def(py::init<const std::string, const int>())
+      .def("infer", &lightseq::cuda::Bert::infer,
+           py::return_value_policy::reference_internal, py::arg("input_seq"),
+           py::arg("attn_mask"));
 }
