@@ -6,7 +6,7 @@ from torch import nn
 from torch.autograd import Function
 
 from lightseq.training.ops.pytorch.builder import TransformerBuilder
-from lightseq.training.ops.pytorch.util import copy_para, MODEL_ARCH
+from lightseq.training.ops.pytorch.util import copy_para, state_dict, MODEL_ARCH
 
 transformer_cuda_module = None
 _all_layer_grads = dict()
@@ -31,12 +31,6 @@ class LSTransformerDecoderFunc(Function):
             else cuda_module.transformer_decoder_layer_fw_fp32
         )
 
-        if config.fp16:
-            decoder_states = decoder_states.to(torch.half)
-            encoder_out = encoder_out.to(torch.half)
-            encoder_padding_mask = encoder_padding_mask.to(torch.half)
-            # cache = [c.to(torch.half) for c in cache]
-
         (output,) = forward_func(
             config.layer_id,
             decoder_states,
@@ -95,7 +89,6 @@ class LSTransformerDecoderFunc(Function):
             grad_enc_out = None
 
         grad = _all_layer_grads[ctx.config.layer_id]
-        ctx.config = None
         return (grad_input, grad_enc_out, None, grad, None, None)
 
 
@@ -339,6 +332,12 @@ class LSTransformerDecoderLayer(nn.Module):
         weights[18] = weights[18].view(-1, hs)
         return weights
 
+    def state_dict(self, destination=None, prefix="", keep_vars=False):
+        destination = state_dict(
+            self, destination=destination, prefix=prefix, keep_vars=keep_vars
+        )
+        return destination
+
     def forward(
         self, decoder_states, encoder_out, encoder_padding_mask, cache, **kwargs
     ):
@@ -366,6 +365,11 @@ class LSTransformerDecoderLayer(nn.Module):
             else:
                 self.register_buffer("para_16", self.para.clone().detach().half())
 
+        if self.config.fp16:
+            decoder_states = decoder_states.to(torch.half)
+            encoder_out = encoder_out.to(torch.half)
+            encoder_padding_mask = encoder_padding_mask.to(torch.half)
+
         self.__assign_layer_weight_grad()
         cache_list = []
         if cache is not None:
@@ -374,23 +378,35 @@ class LSTransformerDecoderLayer(nn.Module):
             if cache:
                 # non-empty dict, step 1-n
                 step = cache["dec_self_k"].shape[2]
-                cache_list = [cache["dec_self_k"], cache["dec_self_v"]]
+                # Thanks to fengjiangtao@bytedance.com
+                # for helping us find this bug.
+                cache_list = [
+                    cache["dec_self_k"].contiguous(),
+                    cache["dec_self_v"].contiguous(),
+                ]
             else:
                 # empty dict, step 0
                 step = 0
-            if self.config.layer_id == 0 and step == 0:
-                shape = (
-                    self.config.nlayer * 2,
-                    encoder_out.shape[0],
-                    encoder_out.shape[1] * self.config.hidden_size,
-                )
-                encdec_kv = torch.zeros(shape).type_as(decoder_states).contiguous()
-                cache["encdec_kv"] = encdec_kv
-                cache_list.append(encdec_kv)
+            if self.config.layer_id == 0:
+                if step == 0:
+                    shape = (
+                        self.config.nlayer * 2,
+                        encoder_out.shape[0],
+                        encoder_out.shape[1] * self.config.hidden_size,
+                    )
+                    encdec_kv = torch.zeros(
+                        shape, dtype=decoder_states.dtype, device=decoder_states.device
+                    ).contiguous()
+                    cache["encdec_kv"] = encdec_kv
+                cache_list.append(cache["encdec_kv"])
             head_dim = int(self.config.hidden_size / self.config.nhead)
             shape = (batch_beams, self.config.nhead, step + 1, head_dim)
-            new_k = torch.zeros(shape).type_as(decoder_states).contiguous()
-            new_v = torch.zeros(shape).type_as(decoder_states).contiguous()
+            new_k = torch.zeros(
+                shape, dtype=decoder_states.dtype, device=decoder_states.device
+            ).contiguous()
+            new_v = torch.zeros(
+                shape, dtype=decoder_states.dtype, device=decoder_states.device
+            ).contiguous()
             cache_list = [new_k, new_v] + cache_list
             cache["dec_self_k"] = new_k
             cache["dec_self_v"] = new_v
@@ -398,10 +414,6 @@ class LSTransformerDecoderLayer(nn.Module):
         bs, sl, dim = decoder_states.size()
         if dim % 256 != 0:
             raise ValueError(f"Hidden dim {dim} is not an integer multiple of 256.")
-        if decoder_states.dtype != self.para.dtype:
-            raise TypeError(
-                f"Inputs type {decoder_states.dtype} is not equal to parameters type {self.para.dtype}."
-            )
         if bs * sl > self.config.max_batch_tokens:
             raise ValueError(
                 f"Batch token numbers {bs * sl} exceeds the limit {self.config.max_batch_tokens}."
@@ -410,6 +422,13 @@ class LSTransformerDecoderLayer(nn.Module):
             raise ValueError(
                 f"Sequence length {sl} exceeds the limit {self.config.max_seq_len}."
             )
+        assert encoder_out.size(0) == encoder_padding_mask.size(0) and encoder_out.size(
+            1
+        ) == encoder_padding_mask.size(1)
+        if cache is None:
+            assert bs == encoder_out.size(0)
+        else:
+            assert bs % encoder_out.size(0) == 0
         output = LSTransformerDecoderFunc.apply(
             decoder_states,
             encoder_out,
