@@ -7,7 +7,7 @@ from torch.autograd import Function
 
 
 from lightseq.training.ops.pytorch.builder import TransformerBuilder
-from lightseq.training.ops.pytorch.util import copy_para, MODEL_ARCH
+from lightseq.training.ops.pytorch.util import copy_para, state_dict, MODEL_ARCH
 
 transformer_cuda_module = None
 _all_layer_grads = dict()
@@ -249,6 +249,12 @@ class LSTransformerEncoderLayer(nn.Module):
         func(param, grad, "TransformerEncoderLayer", self.config.layer_id)
         _all_layer_grads[self.config.layer_id] = grad
 
+    def state_dict(self, destination=None, prefix="", keep_vars=False):
+        destination = state_dict(
+            self, destination=destination, prefix=prefix, keep_vars=keep_vars
+        )
+        return destination
+
     def forward(self, hidden_states, encoder_padding_mask, **kwargs):
         self.config.training = self.training
         self.config.is_grad_enabled = torch.is_grad_enabled()
@@ -275,6 +281,7 @@ class LSTransformerEncoderLayer(nn.Module):
             raise ValueError(
                 f"Sequence length {sl} exceeds the limit {self.config.max_seq_len}."
             )
+        assert bs == encoder_padding_mask.size(0) and sl == encoder_padding_mask.size(1)
         output = LSTransformerEncoderFunc.apply(
             hidden_states,
             encoder_padding_mask,
