@@ -5,6 +5,18 @@ def copy_para(x):
     return torch.nn.Parameter(torch.empty_like(x).copy_(x))
 
 
+def state_dict(module, destination=None, prefix="", keep_vars=False):
+    destination = torch.nn.Module.state_dict(
+        module, destination=destination, prefix=prefix, keep_vars=keep_vars
+    )
+
+    for key in destination.keys():
+        if "para_16" in key:
+            destination.pop(key)
+
+    return destination
+
+
 def base_architecture(args):
     args.setdefault("hidden_size", 512)
     args.setdefault("intermediate_size", 2048)
@@ -13,6 +25,7 @@ def base_architecture(args):
     args.setdefault("activation_dropout_ratio", 0.0)
     args.setdefault("hidden_dropout_ratio", 0.1)
     args.setdefault("pre_layer_norm", True)
+    args.setdefault("activation_fn", "relu")
 
 
 def transformer_base(args):
@@ -35,11 +48,13 @@ def bert_base(args):
     args.setdefault("attn_prob_dropout_ratio", 0.1)
     args.setdefault("activation_dropout_ratio", 0.1)
     args.setdefault("pre_layer_norm", False)
+    args.setdefault("activation_fn", "gelu")
     base_architecture(args)
 
 
 def bert_big(args):
     args.setdefault("pre_layer_norm", False)
+    args.setdefault("activation_fn", "gelu")
     transformer_big(args)
 
 
